@@ -172,15 +172,26 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
             return data
         for log in logs_data:
             for item in log.items:
-                alpha = {
-                    "Timestamp": str(log.timestamp * 1000),
-                    "Data": {
-                        "event": item.key,
-                        "message": item.val.get("err_msg"),
-                        "error_kind": item.val.get("err_type"),
-                        "stack": item.val.get("err_trace"),
-                    },
-                }
+                if type(item.val) == str:
+                    alpha = {
+                        "Timestamp": str(log.timestamp * 1000),
+                        "Data": {
+                            "event": item.key,
+                            "message": item.val,
+                            "error_kind": "Error",
+                            "stack": "",
+                        },
+                    }
+                else:
+                    alpha = {
+                        "Timestamp": str(log.timestamp * 1000),
+                        "Data": {
+                            "event": item.key,
+                            "message": item.val.get("err_msg"),
+                            "error_kind": item.val.get("err_type"),
+                            "stack": item.val.get("err_trace"),
+                        },
+                    }
                 data.append(alpha)
 
         return data
