@@ -207,8 +207,13 @@ def set_tenant_code_reader(**kwargs):
     global tenant_code_reader
     if kwargs.get("reader_type"):
         tenant_code_reader["ReaderType"] = kwargs.get("reader_type")
+    elif kwargs.get("ReaderType"):
+        tenant_code_reader["ReaderType"] = kwargs.get("ReaderType")
+
     if kwargs.get("reader_key"):
         tenant_code_reader["ReaderKey"] = kwargs.get("reader_key")
+    elif kwargs.get("ReaderKey"):
+        tenant_code_reader["ReaderKey"] = kwargs.get("ReaderKey")
 
 
 def set_user_code_reader(**kwargs):
@@ -220,8 +225,13 @@ def set_user_code_reader(**kwargs):
     global user_code_reader
     if kwargs.get("reader_type"):
         user_code_reader["ReaderType"] = kwargs.get("reader_type")
+    elif kwargs.get("ReaderType"):
+        user_code_reader["ReaderType"] = kwargs.get("ReaderType")
+
     if kwargs.get("reader_key"):
         user_code_reader["ReaderKey"] = kwargs.get("reader_key")
+    elif kwargs.get("ReaderKey"):
+        user_code_reader["ReaderKey"] = kwargs.get("ReaderKey")
 
 
 def set_env_code_reader(**kwargs):
@@ -232,9 +242,14 @@ def set_env_code_reader(**kwargs):
     """
     global env_code_reader
     if kwargs.get("reader_type"):
-        user_code_reader["ReaderType"] = kwargs.get("reader_type")
+        env_code_reader["ReaderType"] = kwargs.get("reader_type")
+    elif kwargs.get("ReaderType"):
+        env_code_reader["ReaderType"] = kwargs.get("ReaderType")
+
     if kwargs.get("reader_key"):
-        user_code_reader["ReaderKey"] = kwargs.get("reader_key")
+        env_code_reader["ReaderKey"] = kwargs.get("reader_key")
+    elif kwargs.get("ReaderKey"):
+        env_code_reader["ReaderKey"] = kwargs.get("ReaderKey")
 
 
 def set_carrier_header(**kwargs):
@@ -246,8 +261,13 @@ def set_carrier_header(**kwargs):
     global carrier_header
     if kwargs.get("tracker_name"):
         carrier_header["TrackerName"] = kwargs.get("tracker_name")
+    elif kwargs.get("TrackerName"):
+        carrier_header["TrackerName"] = kwargs.get("TrackerName")
+
     if kwargs.get("trace_id_name"):
         carrier_header["TraceIdName"] = kwargs.get("trace_id_name")
+    elif kwargs.get("TraceIdName"):
+        carrier_header["TraceIdName"] = kwargs.get("TraceIdName")
 
 
 def set_trace_id_name(trace_id_name: str):
