@@ -224,43 +224,56 @@ class FastTracker:
             "CarrierHeader": config.carrier_header,
         }
 
-    def begin_event(self, op: str = ""):
+    def begin_span(self, operation: str = ""):
         """
         log模块开始 类似数据库事务的begin_trasaction
         :param op:
         :return:
         """
         try:
+            if not operation:
+                raise RuntimeError("operation参数必填")
             context = get_context()
-            span = context.active_span()
             self.span = context.new_local_span(op="execute")
             self.span.layer = Layer.Local
             self.span.component = ComponentType.CustomEvent
-            self.span.op = op
-            self.span.pid = span.sid
+            self.span.op = operation
             self.span.start()
             return self
         except Exception as e:
             raise e
 
-    def tag(self, tag_name: str = ""):
+    def set_component(self, name: str = "CustomEvent"):
         if not self.span:
-            raise RuntimeError("请先调用begin_event进行实例化")
-        self.span.tag(Tag(key=ComponentType.CustomEvent, val=tag_name))
+            raise RuntimeError("请先调用begin_span进行实例化")
+        self.span.component = name
 
-    def log(self, log: str = ""):
+    def add_tag(self, key: str = "", val: str = ""):
         if not self.span:
-            raise RuntimeError("请先调用begin_event进行实例化")
-        self.span.logs.append(Log(items=[LogItem(key=ComponentType.CustomEvent, val=self.log_covert(log))]))
+            raise RuntimeError("请先调用begin_span进行实例化")
+        try:
+            self.span.tag(Tag(key=key, val=val))
+        except Exception as e:
+            raise e
+
+    def add_log(self, message: str = ""):
+        if not self.span:
+            raise RuntimeError("请先调用begin_span进行实例化")
+        self.span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(message))]))
+
+    def error_occurred(self, error: Exception):
+        if not self.span:
+            raise RuntimeError("请先调用begin_span进行实例化")
+        self.span.log(error)
 
     def log_covert(self, msg: str = ""):
         return {"err_msg": msg, "err_type": "", "err_trace": ""}
 
-    def end_event(self):
+    def end_span(self):
         """
         log模块结束
         :return:
         """
         if not self.span:
-            raise RuntimeError("请先调用begin_event进行实例化")
+            raise RuntimeError("请先调用begin_span进行实例化")
         self.span.stop()
